@@ -11,8 +11,8 @@ enum class DataInterpreter : uint8_t {
     TEMPERATURE,
     BOSCH_PRESSURE,
     BOSCH_ALTITUDE,
-    BMI160_ROTATION,
-    BMI160_ROTATION_SINGLE_AXIS,
+    BOSCH_ROTATION,
+    BOSCH_ROTATION_SINGLE_AXIS,
     BOSCH_ACCELERATION,
     BOSCH_ACCELERATION_SINGLE_AXIS,
     MMA8452Q_ACCELERATION,
@@ -24,7 +24,7 @@ enum class DataInterpreter : uint8_t {
     TCS34725_COLOR_ADC,
     BME280_HUMIDITY,
     Q16_16_FIXED_POINT,
-    BMI160_ROTATION_UNSIGNED_SINGLE_AXIS,
+    BOSCH_ROTATION_UNSIGNED_SINGLE_AXIS,
     BOSCH_ACCELERATION_UNSIGNED_SINGLE_AXIS,
     MMA8452Q_ACCELERATION_UNSIGNED_SINGLE_AXIS,
     BMM150_B_FIELD_UNSIGNED_SINGLE_AXIS,
@@ -52,7 +52,7 @@ enum class FirmwareConverter : uint8_t {
     BME280_HUMIDITY,
     BOSCH_ACCELERATION,
     BOSCH_BAROMETER,
-    BMI160_ROTATION,
+    BOSCH_ROTATION,
     MMA8452Q_ACCELERATION,
     TEMPERATURE,
     Q16_16_FIXED_POINT,
